--define some constants
local kSummaryHealthBarWidth = 100;
local kSummaryHealthBarHeight = 3;
local kSummaryManaBarWidth = 100;
local kSummaryManaBarHeight = 3;

--Define name space for all WhammySummery functions
WhammySummary = {}

--I left this function name with a _ because it's called from the xml file
--eventually I will build the frame in code instead of xml, but for now it works.
function WhammySummary_OnLoad(self)
	--print("WhammySummary:OnLoad")
	
	self:RegisterForDrag("LeftButton")
	
	WhammySummaryFrame_HealthBar:SetWidth( kSummaryHealthBarWidth );
	WhammySummaryFrame_HealthBar:SetHeight( kSummaryHealthBarHeight );
	
	WhammySummaryFrame_ManaBar:SetWidth( kSummaryManaBarWidth );
	WhammySummaryFrame_ManaBar:SetHeight( kSummaryManaBarHeight );
end

-- called when there is a health changed event to update the party/raid total health bar
function WhammySummary:Update_Total_Health()
	local bar = WhammySummaryFrame_HealthBar
	local numGroupMembers = GetNumGroupMembers();
	local currentUnitHealth, maxUnitHealth, healthFraction = 0,0,0; --need to init these to 0
	
	local playerGroupStatus = Whammy:GetPlayerGroupStatus(); --will return kPlayerAlone, kPlayerInParty or kPlayerInRaid
	
	if ( playerGroupStatus == Whammy.constants.kPlayerAlone ) then
		currentUnitHealth = UnitHealth( "player" ); --get the current player unit health
		maxUnitHealth = UnitHealthMax( "player" ); --get the units max health
	elseif ( playerGroupStatus == Whammy.constants.kPlayerInParty ) then
		currentUnitHealth = UnitHealth( "player" ); --get the current player unit health
		maxUnitHealth = UnitHealthMax( "player" ); --get the units max health
			
		for id = 1,numGroupMembers do --walk through the other party members and gather their max and current health
			currentUnitHealth = currentUnitHealth + UnitHealth( "party"..id ); --get the current unit health
			maxUnitHealth = maxUnitHealth + UnitHealthMax( "party"..id ); --get the units max health
		end
	elseif ( playerGroupStatus == Whammy.constants.kPlayerInRaid ) then
		for id = 1,numGroupMembers do
			currentUnitHealth = currentUnitHealth + UnitHealth( "raid"..id ); --get the current unit health
			maxUnitHealth = maxUnitHealth + UnitHealthMax( "raid"..id ); --get the units max health
		end
	else
		--should never get here
		
	end
	
	healthFraction = currentUnitHealth / maxUnitHealth; -- what % health are all the units at added together
	healthBarAmount = kSummaryHealthBarWidth * healthFraction;
	bar:SetWidth( healthBarAmount ); -- set the raid health bar to the raid health amount
end

function WhammySummary:Event_UnitPower()
	--print("WhammySummery:Event_UnitPower")
	local bar = WhammySummaryFrame_ManaBar
	local cMana = 0 --0 is the mana power type
	local unitCount = 0
	local maxAmount = 0
	local currentAmount = 0
	local numGroupMembers = GetNumGroupMembers();
	local playerGroupStatus = Whammy:GetPlayerGroupStatus(); --will return kPlayerAlone, kPlayerInParty or kPlayerInRaid
		
	if ( playerGroupStatus == Whammy.constants.kPlayerAlone ) then
		if ( UnitPowerType("player") == cMana ) then --if this player uses mana then we will be counting it toward the total
			currentAmount = UnitPower( "player" ); --get the current player unit mana
			maxAmount = UnitPowerMax( "player" ); --get the units max mana
			unitCount = 1;
		end
	elseif ( playerGroupStatus == Whammy.constants.kPlayerInParty ) then
		
		if ( UnitPowerType( "player" ) == cMana ) then --we only care about units that use mana
			currentAmount = UnitPower( "player" ); --get the current player unit mana
			maxAmount = UnitPowerMax( "player" ); --get the units max mana
			unitCount = 1;
		end
		
		
		local numGroupMembers = GetNumGroupMembers();	
		for id = 1,numGroupMembers do --walk through and see if any of the other party members use mana
			local entity = "party"..id
			if ( UnitPowerType( entity ) == cMana ) then --we only care about units that use mana
				currentAmount = currentAmount + UnitPower( entity ); --get the current unit mana
				maxAmount = maxAmount + UnitPowerMax( entity ); --get the units max mana
				unitCount = unitCount + 1;
			end
		end
	elseif ( playerGroupStatus == Whammy.constants.kPlayerInRaid ) then
		
		local numGroupMembers = GetNumGroupMembers();
		for id = 1,numGroupMembers do
			local entity =  "raid"..id
			if ( UnitPowerType( entity ) == cMana ) then --we only care about units that use mana
				currentAmount = currentAmount + UnitPower( entity ); --get the current unit mana
				maxAmount = maxAmount + UnitPowerMax( entity ); --get the units max mana
				unitCount = unitCount + 1;
			end
		end
	else
		--should never get here
		
	end

	if ( unitCount > 0 ) then -- if unit count = 0 then this player is alone and does not use mana, so the mana bar will just reset to full width
		amountFraction = currentAmount / maxAmount; -- what % mana of everyone that uses mana
		manaBarAmount = kSummaryManaBarWidth * amountFraction;
		bar:SetWidth( manaBarAmount ); -- set the raid mana bar to the raid mana amount
	else
		bar:SetWidth( kSummaryManaBarWidth ); -- set the raid mana bar to the raid mana amount
	end
end

